package com.mcwl.communityCenter.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mcwl.common.utils.SecurityUtils;
import com.mcwl.communityCenter.domain.CommunityAdvice;
import com.mcwl.communityCenter.domain.Invite;
import com.mcwl.communityCenter.domain.Publish;
import com.mcwl.communityCenter.domain.Question;
import com.mcwl.communityCenter.domain.dto.QuestionRes;
import com.mcwl.communityCenter.mapper.CommunityAdviceMapper;
import com.mcwl.communityCenter.mapper.PublishMapper;
import com.mcwl.communityCenter.mapper.QuestionMapper;
import com.mcwl.communityCenter.service.InviteService;
import com.mcwl.communityCenter.service.PublishService;
import com.mcwl.communityCenter.service.QuestionService;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;
import java.util.Objects;

@Service
@RequiredArgsConstructor
public class QuestionServiceImpl extends ServiceImpl<QuestionMapper, Question> implements QuestionService {


    private final CommunityAdviceMapper communityAdviceMapper;

    /**
     * 添加问题
     * @param questionRes 问题信息
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void addQuestion(QuestionRes questionRes) {

        Long questionUserId = questionRes.getQuestionUserId();
        Long communityId = questionRes.getCommunityId();
        Long userId = SecurityUtils.getUserId();
        if (Objects.equals(questionUserId, userId)) {
            return;
        }

        // 获取租户id
        Long tenantId = questionRes.getTenantId();

        // 答复人是否是群主
        boolean isInviteUser = !Objects.equals(tenantId, questionUserId);

        if (isInviteUser) {
            return;
        }

        Question question = new Question();
        BeanUtil.copyProperties(questionRes, question);
        baseMapper.insert(question);


        CommunityAdvice communityAdvice = new CommunityAdvice();
        communityAdvice.setTenantId(tenantId);
        communityAdvice.setCommunityId(communityId);
        communityAdvice.setUserId(questionUserId);
        communityAdvice.setTitle("您有新的问题");
        communityAdvice.setContent(questionRes.getContent());
        communityAdviceMapper.insert(communityAdvice);


    }
}
